@@ -97,6 +97,7 @@ private:
 
     ObjectGroup *readObjectGroup();
     MapObject *readObject();
+    QPolygonF readPolygon();
 
     Properties readProperties();
     void readProperty(Properties *properties);
@@ -182,17 +183,6 @@ void MapReaderPrivate::readUnknownElement()
     xml.skipCurrentElement();
 }
 
-static Map::Orientation orientationFromString(const QStringRef &string)
-{
-    Map::Orientation orientation = Map::Unknown;
-    if (string == QLatin1String("orthogonal")) {
-        orientation = Map::Orthogonal;
-    } else if (string == QLatin1String("isometric")) {
-        orientation = Map::Isometric;
-    }
-    return orientation;
-}
-
 Map *MapReaderPrivate::readMap()
 {
     Q_ASSERT(xml.isStartElement() && xml.name() == "map");
@@ -207,14 +197,14 @@ Map *MapReaderPrivate::readMap()
     const int tileHeight =
             atts.value(QLatin1String("tileheight")).toString().toInt();
 
-    const QStringRef orientationRef =
-            atts.value(QLatin1String("orientation"));
+    const QString orientationString =
+            atts.value(QLatin1String("orientation")).toString();
     const Map::Orientation orientation =
-            orientationFromString(orientationRef);
+            orientationFromString(orientationString);
 
     if (orientation == Map::Unknown) {
         xml.raiseError(tr("Unsupported map orientation: \"%1\"")
-                       .arg(orientationRef.toString()));
+                       .arg(orientationString));
     }
 
     mMap = new Map(orientation, mapWidth, mapHeight, tileWidth, tileHeight);
@@ -276,12 +266,21 @@ Tileset *MapReaderPrivate::readTileset()
                                   tileSpacing, margin);
 
             while (xml.readNextStartElement()) {
-                if (xml.name() == "tile")
+                if (xml.name() == "tile") {
                     readTilesetTile(tileset);
-                else if (xml.name() == "image")
+                } else if (xml.name() == "tileoffset") {
+                    const QXmlStreamAttributes oa = xml.attributes();
+                    int x = oa.value(QLatin1String("x")).toString().toInt();
+                    int y = oa.value(QLatin1String("y")).toString().toInt();
+                    tileset->setTileOffset(QPoint(x, y));
+                    xml.skipCurrentElement();
+                } else if (xml.name() == "properties") {
+                    tileset->mergeProperties(readProperties());
+                } else if (xml.name() == "image") {
                     readTilesetImage(tileset);
-                else
+                } else {
                     readUnknownElement();
+                }
             }
         }
     } else { // External tileset
@@ -343,6 +342,10 @@ void MapReaderPrivate::readTilesetImage(Tileset *tileset)
 
     source = p->resolveReference(source, mPath);
 
+    // Set the width that the tileset had when the map was saved
+    const int width = atts.value(QLatin1String("width")).toString().toInt();
+    mGidMapper.setTilesetWidth(tileset, width);
+
     const QImage tilesetImage = p->readExternalImage(source);
     if (!tileset->loadFromImage(tilesetImage, source))
         xml.raiseError(tr("Error loading tileset image:\n'%1'").arg(source));
@@ -564,6 +567,22 @@ ObjectGroup *MapReaderPrivate::readObjectGroup()
     return objectGroup;
 }
 
+static QPointF pixelToTileCoordinates(Map *map, int x, int y)
+{
+    const int tileHeight = map->tileHeight();
+    const int tileWidth = map->tileWidth();
+
+    if (map->orientation() == Map::Isometric) {
+        // Isometric needs special handling, since the pixel values are based
+        // solely on the tile height.
+        return QPointF((qreal) x / tileHeight,
+                       (qreal) y / tileHeight);
+    } else {
+        return QPointF((qreal) x / tileWidth,
+                       (qreal) y / tileHeight);
+    }
+}
+
 MapObject *MapReaderPrivate::readObject()
 {
     Q_ASSERT(xml.isStartElement() && xml.name() == "object");
@@ -577,26 +596,11 @@ MapObject *MapReaderPrivate::readObject()
     const int height = atts.value(QLatin1String("height")).toString().toInt();
     const QString type = atts.value(QLatin1String("type")).toString();
 
-    // Convert pixel coordinates to tile coordinates
-    const int tileHeight = mMap->tileHeight();
-    const int tileWidth = mMap->tileWidth();
-    qreal xF, yF, widthF, heightF;
+    const QPointF pos = pixelToTileCoordinates(mMap, x, y);
+    const QPointF size = pixelToTileCoordinates(mMap, width, height);
 
-    if (mMap->orientation() == Map::Isometric) {
-        // Isometric needs special handling, since the pixel values are based
-        // solely on the tile height.
-        xF = (qreal) x / tileHeight;
-        yF = (qreal) y / tileHeight;
-        widthF = (qreal) width / tileHeight;
-        heightF = (qreal) height / tileHeight;
-    } else {
-        xF = (qreal) x / tileWidth;
-        yF = (qreal) y / tileHeight;
-        widthF = (qreal) width / tileWidth;
-        heightF = (qreal) height / tileHeight;
-    }
-
-    MapObject *object = new MapObject(name, type, xF, yF, widthF, heightF);
+    MapObject *object = new MapObject(name, type, pos, QSizeF(size.x(),
+                                                              size.y()));
 
     if (gid) {
         const Cell cell = cellForGid(gid);
@@ -604,15 +608,59 @@ MapObject *MapReaderPrivate::readObject()
     }
 
     while (xml.readNextStartElement()) {
-        if (xml.name() == "properties")
+        if (xml.name() == "properties") {
             object->mergeProperties(readProperties());
-        else
+        } else if (xml.name() == "polygon") {
+            object->setPolygon(readPolygon());
+            object->setShape(MapObject::Polygon);
+        } else if (xml.name() == "polyline") {
+            object->setPolygon(readPolygon());
+            object->setShape(MapObject::Polyline);
+        } else {
             readUnknownElement();
+        }
     }
 
     return object;
 }
 
+QPolygonF MapReaderPrivate::readPolygon()
+{
+    Q_ASSERT(xml.isStartElement() && (xml.name() == "polygon" ||
+                                      xml.name() == "polyline"));
+
+    const QXmlStreamAttributes atts = xml.attributes();
+    const QString points = atts.value(QLatin1String("points")).toString();
+    const QStringList pointsList = points.split(QLatin1Char(' '),
+                                                QString::SkipEmptyParts);
+
+    QPolygonF polygon;
+    bool ok = true;
+
+    foreach (const QString &point, pointsList) {
+        const int commaPos = point.indexOf(QLatin1Char(','));
+        if (commaPos == -1) {
+            ok = false;
+            break;
+        }
+
+        const int x = point.left(commaPos).toInt(&ok);
+        if (!ok)
+            break;
+        const int y = point.mid(commaPos + 1).toInt(&ok);
+        if (!ok)
+            break;
+
+        polygon.append(pixelToTileCoordinates(mMap, x, y));
+    }
+
+    if (!ok)
+        xml.raiseError(tr("Invalid points data for polygon"));
+
+    xml.skipCurrentElement();
+    return polygon;
+}
+
 Properties MapReaderPrivate::readProperties()
 {
     Q_ASSERT(xml.isStartElement() && xml.name() == "properties");
