@@ -25,6 +25,8 @@
 
 #include <QDialog>
 
+class QModelIndex;
+
 namespace Ui {
 class PreferencesDialog;
 }
@@ -32,6 +34,8 @@ class PreferencesDialog;
 namespace Tiled {
 namespace Internal {
 
+class ObjectTypesModel;
+
 /**
  * The preferences dialog. Allows the user to configure some general behaviour
  * settings of Tiled and choose the language.
@@ -51,6 +55,14 @@ private slots:
     void languageSelected(int index);
     void useOpenGLToggled(bool useOpenGL);
 
+    void addObjectType();
+    void selectedObjectTypesChanged();
+    void removeSelectedObjectTypes();
+    void objectTypeIndexClicked(const QModelIndex &index);
+    void applyObjectTypes();
+    void importObjectTypes();
+    void exportObjectTypes();
+
 private:
     void fromPreferences();
     void toPreferences();
@@ -59,6 +71,7 @@ private:
 
     Ui::PreferencesDialog *mUi;
     QStringList mLanguages;
+    ObjectTypesModel *mObjectTypesModel;
 };
 
 
